# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from elicitlabs import ElicitClient, AsyncElicitClient
from tests.utils import assert_matches_type
from elicitlabs.types import (
    DemoSignInResponse,
    DemoCreateUserResponse,
    DemoResetPasswordResponse,
    DemoGenerateResetLinkResponse,
    DemoRetrieveCurrentUserResponse,
    DemoRequestPasswordResetResponse,
    DemoSubmitEarlyAccessRequestResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDemo:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_user(self, client: ElicitClient) -> None:
        demo = client.demo.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
        )
        assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_user_with_all_params(self, client: ElicitClient) -> None:
        demo = client.demo.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
            org_id="org_id",
        )
        assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_user(self, client: ElicitClient) -> None:
        response = client.demo.with_raw_response.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = response.parse()
        assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_user(self, client: ElicitClient) -> None:
        with client.demo.with_streaming_response.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = response.parse()
            assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_generate_reset_link(self, client: ElicitClient) -> None:
        demo = client.demo.generate_reset_link(
            email="user@example.com",
        )
        assert_matches_type(DemoGenerateResetLinkResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_generate_reset_link(self, client: ElicitClient) -> None:
        response = client.demo.with_raw_response.generate_reset_link(
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = response.parse()
        assert_matches_type(DemoGenerateResetLinkResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_generate_reset_link(self, client: ElicitClient) -> None:
        with client.demo.with_streaming_response.generate_reset_link(
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = response.parse()
            assert_matches_type(DemoGenerateResetLinkResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_request_password_reset(self, client: ElicitClient) -> None:
        demo = client.demo.request_password_reset(
            email="user@example.com",
        )
        assert_matches_type(DemoRequestPasswordResetResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_request_password_reset(self, client: ElicitClient) -> None:
        response = client.demo.with_raw_response.request_password_reset(
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = response.parse()
        assert_matches_type(DemoRequestPasswordResetResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_request_password_reset(self, client: ElicitClient) -> None:
        with client.demo.with_streaming_response.request_password_reset(
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = response.parse()
            assert_matches_type(DemoRequestPasswordResetResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_reset_password(self, client: ElicitClient) -> None:
        demo = client.demo.reset_password(
            token="eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9...",
            confirm_password="newpassword456",
            new_password="newpassword456",
        )
        assert_matches_type(DemoResetPasswordResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_reset_password(self, client: ElicitClient) -> None:
        response = client.demo.with_raw_response.reset_password(
            token="eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9...",
            confirm_password="newpassword456",
            new_password="newpassword456",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = response.parse()
        assert_matches_type(DemoResetPasswordResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_reset_password(self, client: ElicitClient) -> None:
        with client.demo.with_streaming_response.reset_password(
            token="eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9...",
            confirm_password="newpassword456",
            new_password="newpassword456",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = response.parse()
            assert_matches_type(DemoResetPasswordResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_current_user(self, client: ElicitClient) -> None:
        demo = client.demo.retrieve_current_user()
        assert_matches_type(DemoRetrieveCurrentUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_current_user(self, client: ElicitClient) -> None:
        response = client.demo.with_raw_response.retrieve_current_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = response.parse()
        assert_matches_type(DemoRetrieveCurrentUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_current_user(self, client: ElicitClient) -> None:
        with client.demo.with_streaming_response.retrieve_current_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = response.parse()
            assert_matches_type(DemoRetrieveCurrentUserResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_sign_in(self, client: ElicitClient) -> None:
        demo = client.demo.sign_in(
            email="user@example.com",
            password="securepassword123",
        )
        assert_matches_type(DemoSignInResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_sign_in(self, client: ElicitClient) -> None:
        response = client.demo.with_raw_response.sign_in(
            email="user@example.com",
            password="securepassword123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = response.parse()
        assert_matches_type(DemoSignInResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_sign_in(self, client: ElicitClient) -> None:
        with client.demo.with_streaming_response.sign_in(
            email="user@example.com",
            password="securepassword123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = response.parse()
            assert_matches_type(DemoSignInResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_submit_early_access_request(self, client: ElicitClient) -> None:
        demo = client.demo.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
        )
        assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_submit_early_access_request_with_all_params(self, client: ElicitClient) -> None:
        demo = client.demo.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
            company_size="company_size",
            industry="SaaS",
            role="CTO",
        )
        assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_submit_early_access_request(self, client: ElicitClient) -> None:
        response = client.demo.with_raw_response.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = response.parse()
        assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_submit_early_access_request(self, client: ElicitClient) -> None:
        with client.demo.with_streaming_response.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = response.parse()
            assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDemo:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_user(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
        )
        assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_user_with_all_params(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
            org_id="org_id",
        )
        assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_user(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.with_raw_response.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = await response.parse()
        assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_user(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.with_streaming_response.create_user(
            email="user@example.com",
            name="John Doe",
            password="securepassword123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = await response.parse()
            assert_matches_type(DemoCreateUserResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_generate_reset_link(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.generate_reset_link(
            email="user@example.com",
        )
        assert_matches_type(DemoGenerateResetLinkResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_generate_reset_link(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.with_raw_response.generate_reset_link(
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = await response.parse()
        assert_matches_type(DemoGenerateResetLinkResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_generate_reset_link(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.with_streaming_response.generate_reset_link(
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = await response.parse()
            assert_matches_type(DemoGenerateResetLinkResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_request_password_reset(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.request_password_reset(
            email="user@example.com",
        )
        assert_matches_type(DemoRequestPasswordResetResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_request_password_reset(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.with_raw_response.request_password_reset(
            email="user@example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = await response.parse()
        assert_matches_type(DemoRequestPasswordResetResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_request_password_reset(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.with_streaming_response.request_password_reset(
            email="user@example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = await response.parse()
            assert_matches_type(DemoRequestPasswordResetResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_reset_password(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.reset_password(
            token="eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9...",
            confirm_password="newpassword456",
            new_password="newpassword456",
        )
        assert_matches_type(DemoResetPasswordResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_reset_password(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.with_raw_response.reset_password(
            token="eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9...",
            confirm_password="newpassword456",
            new_password="newpassword456",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = await response.parse()
        assert_matches_type(DemoResetPasswordResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_reset_password(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.with_streaming_response.reset_password(
            token="eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9...",
            confirm_password="newpassword456",
            new_password="newpassword456",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = await response.parse()
            assert_matches_type(DemoResetPasswordResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_current_user(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.retrieve_current_user()
        assert_matches_type(DemoRetrieveCurrentUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_current_user(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.with_raw_response.retrieve_current_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = await response.parse()
        assert_matches_type(DemoRetrieveCurrentUserResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_current_user(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.with_streaming_response.retrieve_current_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = await response.parse()
            assert_matches_type(DemoRetrieveCurrentUserResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_sign_in(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.sign_in(
            email="user@example.com",
            password="securepassword123",
        )
        assert_matches_type(DemoSignInResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_sign_in(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.with_raw_response.sign_in(
            email="user@example.com",
            password="securepassword123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = await response.parse()
        assert_matches_type(DemoSignInResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_sign_in(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.with_streaming_response.sign_in(
            email="user@example.com",
            password="securepassword123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = await response.parse()
            assert_matches_type(DemoSignInResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_submit_early_access_request(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
        )
        assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_submit_early_access_request_with_all_params(self, async_client: AsyncElicitClient) -> None:
        demo = await async_client.demo.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
            company_size="company_size",
            industry="SaaS",
            role="CTO",
        )
        assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_submit_early_access_request(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.demo.with_raw_response.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        demo = await response.parse()
        assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_submit_early_access_request(self, async_client: AsyncElicitClient) -> None:
        async with async_client.demo.with_streaming_response.submit_early_access_request(
            email="user@example.com",
            name="John Doe",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            demo = await response.parse()
            assert_matches_type(DemoSubmitEarlyAccessRequestResponse, demo, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["InferenceGenerateMultimodalityCompletionParams"]


class InferenceGenerateMultimodalityCompletionParams(TypedDict, total=False):
    user_id: Required[str]
    """Unique identifier for the user"""

    audio_base64: Optional[str]
    """Base64 encoded audio content (supports webm, wav, mp3, mp4, and other formats)"""

    context: Optional[str]
    """Additional context for the question"""

    disabled_learning: bool
    """Whether to disable learning/ingestion of the multimodal content"""

    image_base64: Optional[str]
    """Base64 encoded image content"""

    model: Optional[str]
    """LLM model to use for generating the response"""

    output_type: Literal["text", "audio", "image"]
    """
    Output type: 'text' for text only, 'audio' for TTS audio, 'image' for
    AI-generated image
    """

    question: Optional[str]
    """User's question or prompt (optional if audio provided)"""

    session_id: Optional[str]
    """Optional session identifier for conversation context"""

    speed: float
    """Speed of the speech (0.25 to 4.0)"""

    video_base64: Optional[str]
    """Base64 encoded video content"""

    voice: str
    """Voice to use for TTS (alloy, echo, fable, onyx, nova, shimmer)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .job_retrieve_status_params import JobRetrieveStatusParams as JobRetrieveStatusParams
from .job_retrieve_status_response import JobRetrieveStatusResponse as JobRetrieveStatusResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..types import user_create_or_get_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.user_create_or_get_response import UserCreateOrGetResponse

__all__ = ["UsersResource", "AsyncUsersResource"]


class UsersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UsersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return UsersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UsersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return UsersResourceWithStreamingResponse(self)

    def create_or_get(
        self,
        *,
        email: str,
        name: str,
        org_user_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserCreateOrGetResponse:
        """
        Create a new user in the UPL system or return existing user.

            This endpoint:
            - Validates authentication tokens
            - Creates a new user with unique email OR returns existing user if email already exists
            - Returns user details upon successful creation or retrieval
            - Uses "create or get" pattern for idempotent behavior

            **Authentication**: Requires valid API key or JWT token in Authorization header

        Args:
          email: User's email address

          name: User's full name

          org_user_id: Organization-specific user ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/users",
            body=maybe_transform(
                {
                    "email": email,
                    "name": name,
                    "org_user_id": org_user_id,
                },
                user_create_or_get_params.UserCreateOrGetParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserCreateOrGetResponse,
        )


class AsyncUsersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUsersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncUsersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUsersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return AsyncUsersResourceWithStreamingResponse(self)

    async def create_or_get(
        self,
        *,
        email: str,
        name: str,
        org_user_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserCreateOrGetResponse:
        """
        Create a new user in the UPL system or return existing user.

            This endpoint:
            - Validates authentication tokens
            - Creates a new user with unique email OR returns existing user if email already exists
            - Returns user details upon successful creation or retrieval
            - Uses "create or get" pattern for idempotent behavior

            **Authentication**: Requires valid API key or JWT token in Authorization header

        Args:
          email: User's email address

          name: User's full name

          org_user_id: Organization-specific user ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/users",
            body=await async_maybe_transform(
                {
                    "email": email,
                    "name": name,
                    "org_user_id": org_user_id,
                },
                user_create_or_get_params.UserCreateOrGetParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserCreateOrGetResponse,
        )


class UsersResourceWithRawResponse:
    def __init__(self, users: UsersResource) -> None:
        self._users = users

        self.create_or_get = to_raw_response_wrapper(
            users.create_or_get,
        )


class AsyncUsersResourceWithRawResponse:
    def __init__(self, users: AsyncUsersResource) -> None:
        self._users = users

        self.create_or_get = async_to_raw_response_wrapper(
            users.create_or_get,
        )


class UsersResourceWithStreamingResponse:
    def __init__(self, users: UsersResource) -> None:
        self._users = users

        self.create_or_get = to_streamed_response_wrapper(
            users.create_or_get,
        )


class AsyncUsersResourceWithStreamingResponse:
    def __init__(self, users: AsyncUsersResource) -> None:
        self._users = users

        self.create_or_get = async_to_streamed_response_wrapper(
            users.create_or_get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

from .._types import SequenceNotStr

__all__ = ["ModalQueryParams"]


class ModalQueryParams(TypedDict, total=False):
    question: Required[str]
    """The question to query against user's memories"""

    user_id: Required[str]
    """Unique identifier for the user"""

    filter_memory_types: Optional[SequenceNotStr[str]]
    """Optional list of memory types to exclude from retrieval.

    Valid types: 'episodic', 'preference', 'identity', 'short_term'
    """

    session_id: Optional[str]
    """Optional session identifier for conversation context"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["KeyCreateParams"]


class KeyCreateParams(TypedDict, total=False):
    label: Optional[str]
    """Optional label for the API key"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["OrgListOrganizationMembersResponse", "User"]


class User(BaseModel):
    """Response model for organization member (user or persona)"""

    id: str
    """User ID or Persona ID"""

    created_at: datetime
    """Creation timestamp"""

    type: str
    """Type: 'user' or 'persona'"""

    description: Optional[str] = None
    """Description (for personas only)"""

    email: Optional[str] = None
    """Email (for users only)"""

    name: Optional[str] = None
    """Name of user or persona"""

    org_id: Optional[str] = None
    """Organization ID (for users only)"""

    org_name: Optional[str] = None
    """Organization name (for users only)"""

    user_id: Optional[str] = None
    """Owner user ID (for personas only)"""


class OrgListOrganizationMembersResponse(BaseModel):
    """Response model for getting users and personas by organization"""

    org_id: str
    """Organization ID"""

    total_count: int
    """Total number of users and personas in the organization"""

    users: List[User]
    """List of users and personas in the organization"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from elicitlabs import ElicitClient, AsyncElicitClient
from tests.utils import assert_matches_type
from elicitlabs.types import DataIngestResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestData:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_ingest(self, client: ElicitClient) -> None:
        data = client.data.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
        )
        assert_matches_type(DataIngestResponse, data, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_ingest_with_all_params(self, client: ElicitClient) -> None:
        data = client.data.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
            filename="filename",
            session_id="session_id",
            timestamp="2024-01-01T12:00:00Z",
        )
        assert_matches_type(DataIngestResponse, data, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_ingest(self, client: ElicitClient) -> None:
        response = client.data.with_raw_response.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        data = response.parse()
        assert_matches_type(DataIngestResponse, data, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_ingest(self, client: ElicitClient) -> None:
        with client.data.with_streaming_response.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            data = response.parse()
            assert_matches_type(DataIngestResponse, data, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncData:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_ingest(self, async_client: AsyncElicitClient) -> None:
        data = await async_client.data.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
        )
        assert_matches_type(DataIngestResponse, data, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_ingest_with_all_params(self, async_client: AsyncElicitClient) -> None:
        data = await async_client.data.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
            filename="filename",
            session_id="session_id",
            timestamp="2024-01-01T12:00:00Z",
        )
        assert_matches_type(DataIngestResponse, data, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_ingest(self, async_client: AsyncElicitClient) -> None:
        response = await async_client.data.with_raw_response.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        data = await response.parse()
        assert_matches_type(DataIngestResponse, data, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_ingest(self, async_client: AsyncElicitClient) -> None:
        async with async_client.data.with_streaming_response.ingest(
            content_type="text",
            payload="From: john@example.com\nTo: jane@example.com\nSubject: Hello\n\nHello Jane!",
            user_id="abc-123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            data = await response.parse()
            assert_matches_type(DataIngestResponse, data, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .auth import (
    AuthResource,
    AsyncAuthResource,
    AuthResourceWithRawResponse,
    AsyncAuthResourceWithRawResponse,
    AuthResourceWithStreamingResponse,
    AsyncAuthResourceWithStreamingResponse,
)
from .data import (
    DataResource,
    AsyncDataResource,
    DataResourceWithRawResponse,
    AsyncDataResourceWithRawResponse,
    DataResourceWithStreamingResponse,
    AsyncDataResourceWithStreamingResponse,
)
from .demo import (
    DemoResource,
    AsyncDemoResource,
    DemoResourceWithRawResponse,
    AsyncDemoResourceWithRawResponse,
    DemoResourceWithStreamingResponse,
    AsyncDemoResourceWithStreamingResponse,
)
from .modal import (
    ModalResource,
    AsyncModalResource,
    ModalResourceWithRawResponse,
    AsyncModalResourceWithRawResponse,
    ModalResourceWithStreamingResponse,
    AsyncModalResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .health import (
    HealthResource,
    AsyncHealthResource,
    HealthResourceWithRawResponse,
    AsyncHealthResourceWithRawResponse,
    HealthResourceWithStreamingResponse,
    AsyncHealthResourceWithStreamingResponse,
)
from .personas import (
    PersonasResource,
    AsyncPersonasResource,
    PersonasResourceWithRawResponse,
    AsyncPersonasResourceWithRawResponse,
    PersonasResourceWithStreamingResponse,
    AsyncPersonasResourceWithStreamingResponse,
)
from .inference import (
    InferenceResource,
    AsyncInferenceResource,
    InferenceResourceWithRawResponse,
    AsyncInferenceResourceWithRawResponse,
    InferenceResourceWithStreamingResponse,
    AsyncInferenceResourceWithStreamingResponse,
)

__all__ = [
    "ModalResource",
    "AsyncModalResource",
    "ModalResourceWithRawResponse",
    "AsyncModalResourceWithRawResponse",
    "ModalResourceWithStreamingResponse",
    "AsyncModalResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
    "DataResource",
    "AsyncDataResource",
    "DataResourceWithRawResponse",
    "AsyncDataResourceWithRawResponse",
    "DataResourceWithStreamingResponse",
    "AsyncDataResourceWithStreamingResponse",
    "HealthResource",
    "AsyncHealthResource",
    "HealthResourceWithRawResponse",
    "AsyncHealthResourceWithRawResponse",
    "HealthResourceWithStreamingResponse",
    "AsyncHealthResourceWithStreamingResponse",
    "AuthResource",
    "AsyncAuthResource",
    "AuthResourceWithRawResponse",
    "AsyncAuthResourceWithRawResponse",
    "AuthResourceWithStreamingResponse",
    "AsyncAuthResourceWithStreamingResponse",
    "PersonasResource",
    "AsyncPersonasResource",
    "PersonasResourceWithRawResponse",
    "AsyncPersonasResourceWithRawResponse",
    "PersonasResourceWithStreamingResponse",
    "AsyncPersonasResourceWithStreamingResponse",
    "InferenceResource",
    "AsyncInferenceResource",
    "InferenceResourceWithRawResponse",
    "AsyncInferenceResourceWithRawResponse",
    "InferenceResourceWithStreamingResponse",
    "AsyncInferenceResourceWithStreamingResponse",
    "DemoResource",
    "AsyncDemoResource",
    "DemoResourceWithRawResponse",
    "AsyncDemoResourceWithRawResponse",
    "DemoResourceWithStreamingResponse",
    "AsyncDemoResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.demo import auth_authenticate_with_google_params
from ..._base_client import make_request_options
from ...types.demo.auth_authenticate_with_google_response import AuthAuthenticateWithGoogleResponse

__all__ = ["AuthResource", "AsyncAuthResource"]


class AuthResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return AuthResourceWithStreamingResponse(self)

    def authenticate_with_google(
        self,
        *,
        credential: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AuthAuthenticateWithGoogleResponse:
        """
        Authenticate user with Google OAuth and return JWT token.

            This endpoint:
            - Verifies Google OAuth credential
            - Creates new user if doesn't exist or links existing account
            - Generates JWT authentication token
            - Sends welcome email for new Google users
            - Returns user information and access token

            **Authentication**: No authentication required

        Args:
          credential: JWT token from Google Sign-In

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/demo/auth/google",
            body=maybe_transform(
                {"credential": credential}, auth_authenticate_with_google_params.AuthAuthenticateWithGoogleParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AuthAuthenticateWithGoogleResponse,
        )


class AsyncAuthResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return AsyncAuthResourceWithStreamingResponse(self)

    async def authenticate_with_google(
        self,
        *,
        credential: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AuthAuthenticateWithGoogleResponse:
        """
        Authenticate user with Google OAuth and return JWT token.

            This endpoint:
            - Verifies Google OAuth credential
            - Creates new user if doesn't exist or links existing account
            - Generates JWT authentication token
            - Sends welcome email for new Google users
            - Returns user information and access token

            **Authentication**: No authentication required

        Args:
          credential: JWT token from Google Sign-In

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/demo/auth/google",
            body=await async_maybe_transform(
                {"credential": credential}, auth_authenticate_with_google_params.AuthAuthenticateWithGoogleParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AuthAuthenticateWithGoogleResponse,
        )


class AuthResourceWithRawResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.authenticate_with_google = to_raw_response_wrapper(
            auth.authenticate_with_google,
        )


class AsyncAuthResourceWithRawResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.authenticate_with_google = async_to_raw_response_wrapper(
            auth.authenticate_with_google,
        )


class AuthResourceWithStreamingResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.authenticate_with_google = to_streamed_response_wrapper(
            auth.authenticate_with_google,
        )


class AsyncAuthResourceWithStreamingResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.authenticate_with_google = async_to_streamed_response_wrapper(
            auth.authenticate_with_google,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["KeyCreateResponse"]


class KeyCreateResponse(BaseModel):
    id: str
    """Unique identifier for the API key"""

    api_key: str
    """The actual API key (only shown once)"""

    created_at: str
    """Creation timestamp"""

    org_id: str
    """Organization ID"""

    user_id: str
    """User ID"""

    label: Optional[str] = None
    """Label for the API key"""

    success: Optional[bool] = None
    """Indicates successful creation"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .auth_authenticate_with_google_params import AuthAuthenticateWithGoogleParams as AuthAuthenticateWithGoogleParams
from .org_list_organization_members_params import OrgListOrganizationMembersParams as OrgListOrganizationMembersParams
from .auth_authenticate_with_google_response import (
    AuthAuthenticateWithGoogleResponse as AuthAuthenticateWithGoogleResponse,
)
from .org_list_organization_members_response import (
    OrgListOrganizationMembersResponse as OrgListOrganizationMembersResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .key_create_params import KeyCreateParams as KeyCreateParams
from .key_list_response import KeyListResponse as KeyListResponse
from .key_create_response import KeyCreateResponse as KeyCreateResponse
from .key_revoke_response import KeyRevokeResponse as KeyRevokeResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["ModalQueryMultimodalityParams"]


class ModalQueryMultimodalityParams(TypedDict, total=False):
    user_id: Required[str]
    """Unique identifier for the user"""

    audio_base64: Optional[str]
    """Base64 encoded audio content (supports webm, wav, mp3, mp4, and other formats)"""

    image_base64: Optional[str]
    """Base64 encoded image content"""

    session_id: Optional[str]
    """Optional session identifier for conversation context"""

    video_base64: Optional[str]
    """Base64 encoded video content"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["UserCreateOrGetParams"]


class UserCreateOrGetParams(TypedDict, total=False):
    email: Required[str]
    """User's email address"""

    name: Required[str]
    """User's full name"""

    org_user_id: Optional[str]
    """Organization-specific user ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ModalLearnResponse"]


class ModalLearnResponse(BaseModel):
    """Response model for learning processing"""

    message: str
    """Status message about the learning process"""

    session_id: str
    """Session identifier used for the learning"""

    job_id: Optional[str] = None
    """Job identifier if processed asynchronously"""

    success: Optional[bool] = None
    """Whether the learning was processed successfully"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .._models import BaseModel

__all__ = ["InferenceGeneratePersonaChatResponse"]


class InferenceGeneratePersonaChatResponse(BaseModel):
    """Response model for persona chat"""

    messages: Optional[List[Dict[str, str]]] = None
    """Formatted messages with memory context"""

    response: Optional[str] = None
    """Generated response content"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["AuthAuthenticateWithGoogleParams"]


class AuthAuthenticateWithGoogleParams(TypedDict, total=False):
    credential: Required[str]
    """JWT token from Google Sign-In"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.data import job_retrieve_status_params
from ..._base_client import make_request_options
from ...types.data.job_retrieve_status_response import JobRetrieveStatusResponse

__all__ = ["JobResource", "AsyncJobResource"]


class JobResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> JobResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return JobResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> JobResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return JobResourceWithStreamingResponse(self)

    def retrieve_status(
        self,
        *,
        job_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> JobRetrieveStatusResponse:
        """
        Retrieve the current processing status of an ingestion job.

            Use the job_id returned from /ingest to check if processing is complete.

            **Request Parameters:**
            - job_id (str, required): Unique identifier from /ingest response

            **Response:**
            - job_id (str): The requested job identifier
            - status (str): Current status - "queued", "processing", "completed", "failed", or "cancelled"

            **Example:**
            ```json
            {
                "job_id": "123e4567-e89b-12d3-a456-426614174000"
            }
            ```

            Returns 200 OK with current status. Poll periodically until status is "completed" or "failed".
            Requires JWT authentication.

        Args:
          job_id: Unique identifier for the job

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/data/job/status",
            body=maybe_transform({"job_id": job_id}, job_retrieve_status_params.JobRetrieveStatusParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=JobRetrieveStatusResponse,
        )


class AsyncJobResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncJobResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncJobResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncJobResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return AsyncJobResourceWithStreamingResponse(self)

    async def retrieve_status(
        self,
        *,
        job_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> JobRetrieveStatusResponse:
        """
        Retrieve the current processing status of an ingestion job.

            Use the job_id returned from /ingest to check if processing is complete.

            **Request Parameters:**
            - job_id (str, required): Unique identifier from /ingest response

            **Response:**
            - job_id (str): The requested job identifier
            - status (str): Current status - "queued", "processing", "completed", "failed", or "cancelled"

            **Example:**
            ```json
            {
                "job_id": "123e4567-e89b-12d3-a456-426614174000"
            }
            ```

            Returns 200 OK with current status. Poll periodically until status is "completed" or "failed".
            Requires JWT authentication.

        Args:
          job_id: Unique identifier for the job

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/data/job/status",
            body=await async_maybe_transform({"job_id": job_id}, job_retrieve_status_params.JobRetrieveStatusParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=JobRetrieveStatusResponse,
        )


class JobResourceWithRawResponse:
    def __init__(self, job: JobResource) -> None:
        self._job = job

        self.retrieve_status = to_raw_response_wrapper(
            job.retrieve_status,
        )


class AsyncJobResourceWithRawResponse:
    def __init__(self, job: AsyncJobResource) -> None:
        self._job = job

        self.retrieve_status = async_to_raw_response_wrapper(
            job.retrieve_status,
        )


class JobResourceWithStreamingResponse:
    def __init__(self, job: JobResource) -> None:
        self._job = job

        self.retrieve_status = to_streamed_response_wrapper(
            job.retrieve_status,
        )


class AsyncJobResourceWithStreamingResponse:
    def __init__(self, job: AsyncJobResource) -> None:
        self._job = job

        self.retrieve_status = async_to_streamed_response_wrapper(
            job.retrieve_status,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable, Optional
from typing_extensions import Literal

import httpx

from ..types import (
    inference_generate_completion_params,
    inference_generate_persona_chat_params,
    inference_generate_multimodality_completion_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.inference_generate_completion_response import InferenceGenerateCompletionResponse
from ..types.inference_generate_persona_chat_response import InferenceGeneratePersonaChatResponse
from ..types.inference_generate_multimodality_completion_response import (
    InferenceGenerateMultimodalityCompletionResponse,
)

__all__ = ["InferenceResource", "AsyncInferenceResource"]


class InferenceResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> InferenceResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return InferenceResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> InferenceResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return InferenceResourceWithStreamingResponse(self)

    def generate_completion(
        self,
        *,
        content: Union[str, Iterable[Dict[str, str]]],
        user_id: str,
        disabled_learning: bool | Omit = omit,
        model: str | Omit = omit,
        session_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InferenceGenerateCompletionResponse:
        """
        Generate personalized AI completion using the Elicit Labs Modal System.

            This endpoint:
            - Takes raw messages or user query
            - Retrieves relevant memories and personalizes the context
            - Generates personalized AI response using the specified LLM model
            - Optionally learns from the conversation (disabled_learning=False)
            - Returns formatted messages with AI response

            **Authentication**: Requires valid API key or JWT token in Authorization header

        Args:
          content: Content to process

          user_id: User ID

          disabled_learning: Whether to disable learning

          model: LLM model to use for generation

          session_id: Session ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/inference/completion",
            body=maybe_transform(
                {
                    "content": content,
                    "user_id": user_id,
                    "disabled_learning": disabled_learning,
                    "model": model,
                    "session_id": session_id,
                },
                inference_generate_completion_params.InferenceGenerateCompletionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InferenceGenerateCompletionResponse,
        )

    def generate_multimodality_completion(
        self,
        *,
        user_id: str,
        audio_base64: Optional[str] | Omit = omit,
        context: Optional[str] | Omit = omit,
        disabled_learning: bool | Omit = omit,
        image_base64: Optional[str] | Omit = omit,
        model: Optional[str] | Omit = omit,
        output_type: Literal["text", "audio", "image"] | Omit = omit,
        question: Optional[str] | Omit = omit,
        session_id: Optional[str] | Omit = omit,
        speed: float | Omit = omit,
        video_base64: Optional[str] | Omit = omit,
        voice: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InferenceGenerateMultimodalityCompletionResponse:
        """
        Generate an AI response using multimodal memory retrieval with flexible output
        types.

            This endpoint:
            1. Accepts multimodal inputs (video, image, audio) - same as multimodal-query
            2. Processes the multimodal input to extract faces, voices, and transcripts
            3. Retrieves relevant memories based on matched identities and transcripts
            4. Generates an LLM response using the memory context and multimodal data
            5. Based on output_type: returns text only, converts to speech (TTS), or generates an image
            6. Returns text response, audio/image (based on output_type), and memory context

            **Request Parameters:**
            - user_id (str, required): User or persona ID
            - question (str, optional): User's question or prompt (can be extracted from audio if not provided)
            - context (str, optional): Additional context for the question
            - session_id (str, optional): Session identifier for conversation context
            - video_base64 (str, optional): Base64 encoded video content
            - image_base64 (str, optional): Base64 encoded image content
            - audio_base64 (str, optional): Base64 encoded audio content (supports webm, wav, mp3, etc.)
            - voice (str, optional): Voice to use for TTS - options: alloy (default), echo, fable, onyx, nova, shimmer
            - speed (float, optional): Speech speed from 0.25 to 4.0 (default: 1.0)
            - model (str, optional): LLM model to use (defaults to gemini-2.5-flash)
            - output_type (str, optional): Output type - 'text' (default), 'audio' (TTS), or 'image' (AI-generated)
            - disabled_learning (bool, optional): Whether to disable ingestion/learning from the content (default: false)

            **Note:** At least one multimodal input (video, image, or audio) is required for memory retrieval.
            When disabled_learning is false, the multimodal content will also be ingested for future memory retrieval.

            **Response:**
            - text_response (str): Generated text response from the LLM
            - audio_base64 (str, optional): Base64 encoded audio (MP3 format) if output_type='audio'
            - audio_format (str, optional): Format of the audio
            - voice_used (str, optional): Voice used for TTS
            - image_base64 (str, optional): Representative image from input
            - generated_image_base64 (str, optional): AI-generated image if output_type='image'
            - memory_context (str, optional): Formatted memory context used for generation
            - raw_results (dict, optional): Raw results from memory retrieval
            - success (bool): True if request succeeded

            **Example:**
            ```json
            {
                "user_id": "user-123",
                "question": "What do you see?",
                "video_base64": "base64_encoded_video...",
                "voice": "alloy",
                "speed": 1.0,
                "model": "gemini-2.5-flash",
                "output_type": "audio",
                "disabled_learning": false
            }
            ```

            Returns 200 OK with text, audio/image (based on output_type), and memory context. Requires JWT authentication.

        Args:
          user_id: Unique identifier for the user

          audio_base64: Base64 encoded audio content (supports webm, wav, mp3, mp4, and other formats)

          context: Additional context for the question

          disabled_learning: Whether to disable learning/ingestion of the multimodal content

          image_base64: Base64 encoded image content

          model: LLM model to use for generating the response

          output_type: Output type: 'text' for text only, 'audio' for TTS audio, 'image' for
              AI-generated image

          question: User's question or prompt (optional if audio provided)

          session_id: Optional session identifier for conversation context

          speed: Speed of the speech (0.25 to 4.0)

          video_base64: Base64 encoded video content

          voice: Voice to use for TTS (alloy, echo, fable, onyx, nova, shimmer)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/inference/multimodality-completion",
            body=maybe_transform(
                {
                    "user_id": user_id,
                    "audio_base64": audio_base64,
                    "context": context,
                    "disabled_learning": disabled_learning,
                    "image_base64": image_base64,
                    "model": model,
                    "output_type": output_type,
                    "question": question,
                    "session_id": session_id,
                    "speed": speed,
                    "video_base64": video_base64,
                    "voice": voice,
                },
                inference_generate_multimodality_completion_params.InferenceGenerateMultimodalityCompletionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InferenceGenerateMultimodalityCompletionResponse,
        )

    def generate_persona_chat(
        self,
        *,
        content: Union[str, Iterable[Dict[str, str]]],
        user_id: str,
        disabled_learning: bool | Omit = omit,
        model: str | Omit = omit,
        session_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InferenceGeneratePersonaChatResponse:
        """
        Generate AI response as a specific persona with Elicit Labs Modal System.

            This endpoint:
            - Retrieves persona information and characteristics
            - Formats messages with persona-specific context and memories
            - Generates response in the persona's unique style and voice
            - Optionally learns from the conversation (disabled_learning=False)
            - Returns synchronous response with formatted messages

            **Authentication**: Requires valid API key or JWT token in Authorization header

        Args:
          content: Content to process

          user_id: User ID (persona ID)

          disabled_learning: Whether to disable learning

          model: LLM model to use for generation

          session_id: Session identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/inference/persona-chat",
            body=maybe_transform(
                {
                    "content": content,
                    "user_id": user_id,
                    "disabled_learning": disabled_learning,
                    "model": model,
                    "session_id": session_id,
                },
                inference_generate_persona_chat_params.InferenceGeneratePersonaChatParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InferenceGeneratePersonaChatResponse,
        )


class AsyncInferenceResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncInferenceResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncInferenceResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncInferenceResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/ElicitLabs/elicitlabs-python-sdk#with_streaming_response
        """
        return AsyncInferenceResourceWithStreamingResponse(self)

    async def generate_completion(
        self,
        *,
        content: Union[str, Iterable[Dict[str, str]]],
        user_id: str,
        disabled_learning: bool | Omit = omit,
        model: str | Omit = omit,
        session_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InferenceGenerateCompletionResponse:
        """
        Generate personalized AI completion using the Elicit Labs Modal System.

            This endpoint:
            - Takes raw messages or user query
            - Retrieves relevant memories and personalizes the context
            - Generates personalized AI response using the specified LLM model
            - Optionally learns from the conversation (disabled_learning=False)
            - Returns formatted messages with AI response

            **Authentication**: Requires valid API key or JWT token in Authorization header

        Args:
          content: Content to process

          user_id: User ID

          disabled_learning: Whether to disable learning

          model: LLM model to use for generation

          session_id: Session ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/inference/completion",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "user_id": user_id,
                    "disabled_learning": disabled_learning,
                    "model": model,
                    "session_id": session_id,
                },
                inference_generate_completion_params.InferenceGenerateCompletionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InferenceGenerateCompletionResponse,
        )

    async def generate_multimodality_completion(
        self,
        *,
        user_id: str,
        audio_base64: Optional[str] | Omit = omit,
        context: Optional[str] | Omit = omit,
        disabled_learning: bool | Omit = omit,
        image_base64: Optional[str] | Omit = omit,
        model: Optional[str] | Omit = omit,
        output_type: Literal["text", "audio", "image"] | Omit = omit,
        question: Optional[str] | Omit = omit,
        session_id: Optional[str] | Omit = omit,
        speed: float | Omit = omit,
        video_base64: Optional[str] | Omit = omit,
        voice: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InferenceGenerateMultimodalityCompletionResponse:
        """
        Generate an AI response using multimodal memory retrieval with flexible output
        types.

            This endpoint:
            1. Accepts multimodal inputs (video, image, audio) - same as multimodal-query
            2. Processes the multimodal input to extract faces, voices, and transcripts
            3. Retrieves relevant memories based on matched identities and transcripts
            4. Generates an LLM response using the memory context and multimodal data
            5. Based on output_type: returns text only, converts to speech (TTS), or generates an image
            6. Returns text response, audio/image (based on output_type), and memory context

            **Request Parameters:**
            - user_id (str, required): User or persona ID
            - question (str, optional): User's question or prompt (can be extracted from audio if not provided)
            - context (str, optional): Additional context for the question
            - session_id (str, optional): Session identifier for conversation context
            - video_base64 (str, optional): Base64 encoded video content
            - image_base64 (str, optional): Base64 encoded image content
            - audio_base64 (str, optional): Base64 encoded audio content (supports webm, wav, mp3, etc.)
            - voice (str, optional): Voice to use for TTS - options: alloy (default), echo, fable, onyx, nova, shimmer
            - speed (float, optional): Speech speed from 0.25 to 4.0 (default: 1.0)
            - model (str, optional): LLM model to use (defaults to gemini-2.5-flash)
            - output_type (str, optional): Output type - 'text' (default), 'audio' (TTS), or 'image' (AI-generated)
            - disabled_learning (bool, optional): Whether to disable ingestion/learning from the content (default: false)

            **Note:** At least one multimodal input (video, image, or audio) is required for memory retrieval.
            When disabled_learning is false, the multimodal content will also be ingested for future memory retrieval.

            **Response:**
            - text_response (str): Generated text response from the LLM
            - audio_base64 (str, optional): Base64 encoded audio (MP3 format) if output_type='audio'
            - audio_format (str, optional): Format of the audio
            - voice_used (str, optional): Voice used for TTS
            - image_base64 (str, optional): Representative image from input
            - generated_image_base64 (str, optional): AI-generated image if output_type='image'
            - memory_context (str, optional): Formatted memory context used for generation
            - raw_results (dict, optional): Raw results from memory retrieval
            - success (bool): True if request succeeded

            **Example:**
            ```json
            {
                "user_id": "user-123",
                "question": "What do you see?",
                "video_base64": "base64_encoded_video...",
                "voice": "alloy",
                "speed": 1.0,
                "model": "gemini-2.5-flash",
                "output_type": "audio",
                "disabled_learning": false
            }
            ```

            Returns 200 OK with text, audio/image (based on output_type), and memory context. Requires JWT authentication.

        Args:
          user_id: Unique identifier for the user

          audio_base64: Base64 encoded audio content (supports webm, wav, mp3, mp4, and other formats)

          context: Additional context for the question

          disabled_learning: Whether to disable learning/ingestion of the multimodal content

          image_base64: Base64 encoded image content

          model: LLM model to use for generating the response

          output_type: Output type: 'text' for text only, 'audio' for TTS audio, 'image' for
              AI-generated image

          question: User's question or prompt (optional if audio provided)

          session_id: Optional session identifier for conversation context

          speed: Speed of the speech (0.25 to 4.0)

          video_base64: Base64 encoded video content

          voice: Voice to use for TTS (alloy, echo, fable, onyx, nova, shimmer)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/inference/multimodality-completion",
            body=await async_maybe_transform(
                {
                    "user_id": user_id,
                    "audio_base64": audio_base64,
                    "context": context,
                    "disabled_learning": disabled_learning,
                    "image_base64": image_base64,
                    "model": model,
                    "output_type": output_type,
                    "question": question,
                    "session_id": session_id,
                    "speed": speed,
                    "video_base64": video_base64,
                    "voice": voice,
                },
                inference_generate_multimodality_completion_params.InferenceGenerateMultimodalityCompletionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InferenceGenerateMultimodalityCompletionResponse,
        )

    async def generate_persona_chat(
        self,
        *,
        content: Union[str, Iterable[Dict[str, str]]],
        user_id: str,
        disabled_learning: bool | Omit = omit,
        model: str | Omit = omit,
        session_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InferenceGeneratePersonaChatResponse:
        """
        Generate AI response as a specific persona with Elicit Labs Modal System.

            This endpoint:
            - Retrieves persona information and characteristics
            - Formats messages with persona-specific context and memories
            - Generates response in the persona's unique style and voice
            - Optionally learns from the conversation (disabled_learning=False)
            - Returns synchronous response with formatted messages

            **Authentication**: Requires valid API key or JWT token in Authorization header

        Args:
          content: Content to process

          user_id: User ID (persona ID)

          disabled_learning: Whether to disable learning

          model: LLM model to use for generation

          session_id: Session identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/inference/persona-chat",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "user_id": user_id,
                    "disabled_learning": disabled_learning,
                    "model": model,
                    "session_id": session_id,
                },
                inference_generate_persona_chat_params.InferenceGeneratePersonaChatParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InferenceGeneratePersonaChatResponse,
        )


class InferenceResourceWithRawResponse:
    def __init__(self, inference: InferenceResource) -> None:
        self._inference = inference

        self.generate_completion = to_raw_response_wrapper(
            inference.generate_completion,
        )
        self.generate_multimodality_completion = to_raw_response_wrapper(
            inference.generate_multimodality_completion,
        )
        self.generate_persona_chat = to_raw_response_wrapper(
            inference.generate_persona_chat,
        )


class AsyncInferenceResourceWithRawResponse:
    def __init__(self, inference: AsyncInferenceResource) -> None:
        self._inference = inference

        self.generate_completion = async_to_raw_response_wrapper(
            inference.generate_completion,
        )
        self.generate_multimodality_completion = async_to_raw_response_wrapper(
            inference.generate_multimodality_completion,
        )
        self.generate_persona_chat = async_to_raw_response_wrapper(
            inference.generate_persona_chat,
        )


class InferenceResourceWithStreamingResponse:
    def __init__(self, inference: InferenceResource) -> None:
        self._inference = inference

        self.generate_completion = to_streamed_response_wrapper(
            inference.generate_completion,
        )
        self.generate_multimodality_completion = to_streamed_response_wrapper(
            inference.generate_multimodality_completion,
        )
        self.generate_persona_chat = to_streamed_response_wrapper(
            inference.generate_persona_chat,
        )


class AsyncInferenceResourceWithStreamingResponse:
    def __init__(self, inference: AsyncInferenceResource) -> None:
        self._inference = inference

        self.generate_completion = async_to_streamed_response_wrapper(
            inference.generate_completion,
        )
        self.generate_multimodality_completion = async_to_streamed_response_wrapper(
            inference.generate_multimodality_completion,
        )
        self.generate_persona_chat = async_to_streamed_response_wrapper(
            inference.generate_persona_chat,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

__all__ = ["ModalLearnParams"]


class ModalLearnParams(TypedDict, total=False):
    message: Required[Dict[str, object]]
    """Single message to learn from with 'role' and 'content' fields"""

    user_id: Required[str]
    """Unique identifier for the user"""

    session_id: Optional[str]
    """Optional session identifier for conversation context"""

    timestamp: Optional[str]
    """ISO format datetime string for the message timestamp"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["PersonaListResponse", "Persona"]


class Persona(BaseModel):
    """Response model for persona information"""

    created_at: datetime

    description: Optional[str] = None

    name: str

    persona_id: str

    user_email: Optional[str] = None

    user_id: str

    user_name: Optional[str] = None


class PersonaListResponse(BaseModel):
    """Response model for getting user personas"""

    personas: List[Persona]
    """List of personas for the user"""

    total_count: int
    """Total number of personas for the user"""

    user_id: str
    """User ID"""
